@@ -1230,6 +1230,10 @@ class RunAndMail(Subcommand):
     description = __doc__.strip()
 
     def add_parser_args(self, parser):
+
+        parser.add_argument('--skip-if-empty', action='store_true',
+                            help="Skip sending the email if the command generates no output.")
+
         parser.add_argument('--key', default='run_n_mail',
                             help="Config key for email settings")
         # TODO: these all seem like good ideas, but not needed yet?
@@ -1270,6 +1274,10 @@ class RunAndMail(Subcommand):
         runtime = run_ended - run_began
         runtime_pretty = humanize.naturaldelta(runtime)
 
+        if args.skip_if_empty and not output:
+            log.info("command had no output, so will skip sending email")
+            return
+
         kwargs = {}
         if args.subject:
             kwargs['subject_template'] = args.subject
