@@ -505,6 +505,20 @@ class RattailConfig(object):
         # NOTE: we don't allow command to be specified in DB, for security reasons..
         return self.getlist('rattail.upgrades', 'command', default=default, usedb=False)
 
+    def base_url(self):
+        """
+        Returns the configured "base" (root) URL for the web app.
+        """
+        # first try "generic" config option
+        url = self.get('rattail', 'base_url')
+
+        # or use tailbone as fallback, since it's most likely
+        if url is None:
+            url = self.get('tailbone', 'url')
+
+        if url is not None:
+            return url.rstrip('/')
+
     def datasync_url(self):
         """
         Returns configured URL for managing datasync daemon.
