@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -28,9 +28,10 @@ from __future__ import unicode_literals, absolute_import
 
 import re
 import datetime
+import decimal
 import logging
-from decimal import Decimal
 
+import six
 import xlrd
 
 from rattail.db import model
@@ -65,7 +66,7 @@ class DutchValleyCatalogParser(CatalogParser):
             # Product code is in first column...but so is a lot of other
             # garbage.  Use strict regex to find good rows.
             code = sheet.cell_value(r, 0)
-            if not isinstance(code, basestring):
+            if not isinstance(code, six.string_types):
                 continue
             if not code_pattern.match(code):
                 continue
@@ -88,13 +89,13 @@ class DutchValleyCatalogParser(CatalogParser):
 
             case_cost = sheet.cell_value(r, 2)
             try:
-                row.case_cost = Decimal(unicode(case_cost))
+                row.case_cost = decimal.Decimal(six.text_type(case_cost))
             except ValueError:
                 log.warning("bad case cost at row {0}: {1}".format(r + 1, repr(case_cost)))
 
             unit_cost = sheet.cell_value(r, 4)
             try:
-                row.unit_cost = Decimal(unicode(unit_cost))
+                row.unit_cost = decimal.Decimal(six.text_type(unit_cost))
             except ValueError:
                 log.warning("bad unit cost at row {0}: {1}".format(r + 1, repr(unit_cost)))
 
