@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -30,6 +30,7 @@ import re
 import datetime
 from decimal import Decimal
 
+import six
 import xlrd
 
 from rattail.db import model
@@ -84,8 +85,8 @@ class UNFICatalogParser(CatalogParser):
             row.description = sheet.cell_value(r, 3)
             row.size = sheet.cell_value(r, 5)
             row.case_size = int(sheet.cell_value(r, 4))
-            row.case_cost = Decimal(unicode(sheet.cell_value(r, 8)))
-            row.unit_cost = Decimal(unicode(sheet.cell_value(r, 9)))
+            row.case_cost = Decimal(six.text_type(sheet.cell_value(r, 8)))
+            row.unit_cost = Decimal(six.text_type(sheet.cell_value(r, 9)))
             yield row
 
 
@@ -120,6 +121,6 @@ class UNFICatalogParser2(UNFICatalogParser):
             row.description = sheet.cell_value(r, 4)
             row.size = sheet.cell_value(r, 7)
             row.case_size = int(sheet.cell_value(r, 6))
-            row.case_cost = Decimal(unicode(sheet.cell_value(r, 10)))
-            row.unit_cost = Decimal(unicode(sheet.cell_value(r, 11)))
+            row.case_cost = Decimal(six.text_type(sheet.cell_value(r, 10)))
+            row.unit_cost = Decimal(six.text_type(sheet.cell_value(r, 11)))
             yield row
