@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -115,8 +115,14 @@ class NewDataSyncImportConsumer(DataSyncConsumer):
     skip_local_models = []
 
     def __init__(self, *args, **kwargs):
-        self.handler_spec = kwargs.pop('handler_spec', self.handler_spec)
         super(NewDataSyncImportConsumer, self).__init__(*args, **kwargs)
+
+        self.handler_spec = kwargs.pop('handler_spec', self.handler_spec)
+
+        self.handler = load_object(self.handler_spec)
+        if not isinstance(self.handler, importing.ImportHandler):
+            self.handler = self.handler(config=self.config)
+
         self.importers = self.get_importers()
 
     def get_importers(self):
@@ -131,10 +137,8 @@ class NewDataSyncImportConsumer(DataSyncConsumer):
            values, coming from the host system.  Or at least that's what will
            make life easy for the :meth:`invoke_importer()` method.
         """
-        handler = load_object(self.handler_spec)
-
         importers = self.get_importers_from_handler(
-            handler, default_only=self.default_importers_only)
+            self.handler, default_only=self.default_importers_only)
 
         for host_name, local_name in self.model_map.items():
             if local_name in importers:
@@ -148,9 +152,6 @@ class NewDataSyncImportConsumer(DataSyncConsumer):
         return importers
 
     def get_importers_from_handler(self, handler, default_only=True):
-        if not isinstance(handler, importing.ImportHandler):
-            handler = handler(config=self.config)
-
         if default_only:
             keys = handler.get_default_keys()
         else:
