@@ -49,7 +49,8 @@ from .products import (Brand, Tax, Product, ProductImage, ProductCode,
 from .purchase import (PurchaseBase, PurchaseItemBase, PurchaseCreditBase,
                        Purchase, PurchaseItem, PurchaseCredit)
 
-from .custorders import CustomerOrder, CustomerOrderItem, CustomerOrderItemEvent
+from .custorders import (CustomerOrderBase, CustomerOrderItemBase,
+                         CustomerOrder, CustomerOrderItem, CustomerOrderItemEvent)
 
 from .messages import Message, MessageRecipient
 
@@ -70,5 +71,6 @@ from .batch.newproduct import NewProductBatch, NewProductBatchRow
 from .batch.pricing import PricingBatch, PricingBatchRow
 from .batch.product import ProductBatch, ProductBatchRow
 from .batch.purchase import PurchaseBatch, PurchaseBatchRow, PurchaseBatchRowClaim, PurchaseBatchCredit
+from .batch.custorder import CustomerOrderBatch, CustomerOrderBatchRow
 from .batch.vendorcatalog import VendorCatalog, VendorCatalogRow
 from .batch.vendorinvoice import VendorInvoice, VendorInvoiceRow
