@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,6 +32,7 @@ from __future__ import unicode_literals, absolute_import
 import os
 import datetime
 import shutil
+import warnings
 
 import six
 import sqlalchemy as sa
@@ -257,6 +258,10 @@ class BatchMixin(object):
         """
         Delete the data folder for the batch
         """
+        warnings.warn("This method has been deprecated; please see/use "
+                      "BatchHandler.delete_extra_data() instead",
+                      DeprecationWarning)
+
         # TODO: should this logic be in the handler instead?
         path = config.batch_filepath(self.batch_key, self.uuid)
         if os.path.exists(path):
