@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,10 +26,12 @@ Rattail -> Rattail data import
 
 from __future__ import unicode_literals, absolute_import
 
+import sqlalchemy as sa
+
 from rattail.db import Session
 from rattail.importing import model
 from rattail.importing.handlers import FromSQLAlchemyHandler, ToSQLAlchemyHandler
-from rattail.importing.sqlalchemy import FromSQLAlchemy
+from rattail.importing.sqlalchemy import FromSQLAlchemySameToSame
 from rattail.util import OrderedDict
 
 
@@ -50,7 +52,10 @@ class ToRattailHandler(ToSQLAlchemyHandler):
     local_title = "Rattail"
 
     def make_session(self):
-        return Session()
+        kwargs = {}
+        if hasattr(self, 'runas_user'):
+            kwargs['continuum_user'] = self.runas_user
+        return Session(**kwargs)
 
     def begin_local_transaction(self):
         self.session = self.make_session()
@@ -66,11 +71,13 @@ class FromRattailToRattailBase(object):
     def get_importers(self):
         importers = OrderedDict()
         importers['Person'] = PersonImporter
+        importers['GlobalPerson'] = GlobalPersonImporter
         importers['PersonEmailAddress'] = PersonEmailAddressImporter
         importers['PersonPhoneNumber'] = PersonPhoneNumberImporter
         importers['PersonMailingAddress'] = PersonMailingAddressImporter
         importers['User'] = UserImporter
         importers['AdminUser'] = AdminUserImporter
+        importers['GlobalUser'] = GlobalUserImporter
         importers['Message'] = MessageImporter
         importers['MessageRecipient'] = MessageRecipientImporter
         importers['Store'] = StoreImporter
@@ -87,6 +94,9 @@ class FromRattailToRattailBase(object):
         importers['CustomerPerson'] = CustomerPersonImporter
         importers['CustomerEmailAddress'] = CustomerEmailAddressImporter
         importers['CustomerPhoneNumber'] = CustomerPhoneNumberImporter
+        importers['Member'] = MemberImporter
+        importers['MemberEmailAddress'] = MemberEmailAddressImporter
+        importers['MemberPhoneNumber'] = MemberPhoneNumberImporter
         importers['Vendor'] = VendorImporter
         importers['VendorEmailAddress'] = VendorEmailAddressImporter
         importers['VendorPhoneNumber'] = VendorPhoneNumberImporter
@@ -99,96 +109,117 @@ class FromRattailToRattailBase(object):
         importers['ReportCode'] = ReportCodeImporter
         importers['DepositLink'] = DepositLinkImporter
         importers['Tax'] = TaxImporter
+        importers['InventoryAdjustmentReason'] = InventoryAdjustmentReasonImporter
         importers['Brand'] = BrandImporter
         importers['Product'] = ProductImporter
         importers['ProductCode'] = ProductCodeImporter
         importers['ProductCost'] = ProductCostImporter
         importers['ProductPrice'] = ProductPriceImporter
         importers['ProductStoreInfo'] = ProductStoreInfoImporter
+        importers['ProductVolatile'] = ProductVolatileImporter
         importers['ProductImage'] = ProductImageImporter
+        importers['LabelProfile'] = LabelProfileImporter
         return importers
 
     def get_default_keys(self):
         keys = self.get_importer_keys()
-        if 'AdminUser' in keys:
-            keys.remove('AdminUser')
-        if 'ProductImage' in keys:
-            keys.remove('ProductImage')
+
+        avoid_by_default = [
+            'GlobalPerson',
+            'AdminUser',
+            'GlobalUser',
+            'ProductImage',
+        ]
+
+        for key in avoid_by_default:
+            if key in keys:
+                keys.remove(key)
+
         return keys
 
 
 class FromRattailToRattailImport(FromRattailToRattailBase, FromRattailHandler, ToRattailHandler):
     """
-    Handler for Rattail -> Rattail data import.
+    Handler for Rattail (other) -> Rattail (local) data import.
+
+    .. attribute:: direction
+
+       Value is ``'import'`` - see also
+       :attr:`rattail.importing.handlers.ImportHandler.direction`.
     """
-    local_title = "Rattail (local)"
     dbkey = 'host'
 
     @property
     def host_title(self):
-        return "Rattail ({})".format(self.dbkey)
+        return "{} ({})".format(self.config.app_title(default="Rattail"), self.dbkey)
+
+    @property
+    def local_title(self):
+        return self.config.node_title(default="Rattail (local)")
 
     def make_host_session(self):
         return Session(bind=self.config.rattail_engines[self.dbkey])
 
-# TODO: deprecate/remove this?
-FromRattailToRattail = FromRattailToRattailImport
-
 
 class FromRattailToRattailExport(FromRattailToRattailBase, FromRattailHandler, ToRattailHandler):
     """
-    Handler for Rattail -> Rattail data import.
+    Handler for Rattail (local) -> Rattail (other) data export.
+
+    .. attribute:: direction
+
+       Value is ``'export'`` - see also
+       :attr:`rattail.importing.handlers.ImportHandler.direction`.
     """
-    host_title = "Rattail (default)"
+    direction = 'export'
+
+    @property
+    def host_title(self):
+        return self.config.node_title()
 
     @property
     def local_title(self):
-        return "Rattail ({})".format(self.dbkey)
+        return "{} ({})".format(self.config.app_title(default="Rattail"), self.dbkey)
 
     def make_session(self):
         return Session(bind=self.config.rattail_engines[self.dbkey])
 
 
-class FromRattail(FromSQLAlchemy):
+class FromRattail(FromSQLAlchemySameToSame):
     """
     Base class for Rattail -> Rattail data importers.
     """
 
-    @property
-    def host_model_class(self):
-        return self.model_class
-
-    @property
-    def supported_fields(self):
-        """
-        We only need to support the simple fields in a Rattail->Rattail import,
-        since all relevant tables should be covered and therefore no need to do
-        crazy foreign key acrobatics etc.
-        """
-        return self.simple_fields
-
-    def query(self):
-        """
-        Leverage the same caching optimizations on both sides, if applicable.
-        """
-        query = super(FromRattail, self).query()
-        if hasattr(self, 'cache_query_options'):
-            options = self.cache_query_options()
-            if options:
-                for option in options:
-                    query = query.options(option)
-        return query
-
-    def normalize_host_object(self, obj):
-        """
-        Normalization should work the same for both sides.
-        """
-        return self.normalize_local_object(obj)
-
 
 class PersonImporter(FromRattail, model.PersonImporter):
     pass
 
+
+class GlobalPersonImporter(FromRattail, model.GlobalPersonImporter):
+    """
+    This is a customized version of the :class:`PersonImporter`, which simply
+    avoids "local only" person accounts.
+    """
+
+    def query(self):
+        query = super(GlobalPersonImporter, self).query()
+
+        # never include "local only" people
+        query = query.filter(sa.or_(
+            self.host_model_class.local_only == False,
+            self.host_model_class.local_only == None))
+
+        return query
+
+    def normalize_host_object(self, person):
+
+        # must check this here for sake of datasync
+        if person.local_only:
+            return
+
+        data = super(GlobalPersonImporter, self).normalize_host_object(person)
+        return data
+
+
 class PersonEmailAddressImporter(FromRattail, model.PersonEmailAddressImporter):
     pass
 
@@ -201,6 +232,33 @@ class PersonMailingAddressImporter(FromRattail, model.PersonMailingAddressImport
 class UserImporter(FromRattail, model.UserImporter):
     pass
 
+
+class GlobalUserImporter(FromRattail, model.GlobalUserImporter):
+    """
+    This is a customized version of the :class:`UserImporter`, which simply
+    avoids "local only" user accounts.
+    """
+
+    def query(self):
+        query = super(GlobalUserImporter, self).query()
+
+        # never include "local only" users
+        query = query.filter(sa.or_(
+            self.host_model_class.local_only == False,
+            self.host_model_class.local_only == None))
+
+        return query
+
+    def normalize_host_object(self, user):
+
+        # must check this here for sake of datasync
+        if user.local_only:
+            return
+
+        data = super(GlobalUserImporter, self).normalize_host_object(user)
+        return data
+
+
 class AdminUserImporter(FromRattail, model.AdminUserImporter):
 
     @property
@@ -211,8 +269,8 @@ class AdminUserImporter(FromRattail, model.AdminUserImporter):
 
     def normalize_host_object(self, user):
         data = super(AdminUserImporter, self).normalize_local_object(user) # sic
-        if 'admin' in self.fields:
-            data['admin'] = self.get_admin(self.host_session) in user.roles
+        if 'admin' in self.fields: # TODO: do we really need this, after the above?
+            data['admin'] = self.admin_uuid in [r.role_uuid for r in user._roles]
         return data
 
 
@@ -267,6 +325,15 @@ class CustomerEmailAddressImporter(FromRattail, model.CustomerEmailAddressImport
 class CustomerPhoneNumberImporter(FromRattail, model.CustomerPhoneNumberImporter):
     pass
 
+class MemberImporter(FromRattail, model.MemberImporter):
+    pass
+
+class MemberEmailAddressImporter(FromRattail, model.MemberEmailAddressImporter):
+    pass
+
+class MemberPhoneNumberImporter(FromRattail, model.MemberPhoneNumberImporter):
+    pass
+
 class VendorImporter(FromRattail, model.VendorImporter):
     pass
 
@@ -300,20 +367,38 @@ class DepositLinkImporter(FromRattail, model.DepositLinkImporter):
 class TaxImporter(FromRattail, model.TaxImporter):
     pass
 
+class InventoryAdjustmentReasonImporter(FromRattail, model.InventoryAdjustmentReasonImporter):
+    pass
+
 class BrandImporter(FromRattail, model.BrandImporter):
     pass
 
 class ProductImporter(FromRattail, model.ProductImporter):
 
-    # TODO...
     @property
     def simple_fields(self):
         fields = super(ProductImporter, self).simple_fields
-        fields.remove('unit_uuid')
+        # NOTE: it seems we can't consider these "simple" due to the
+        # self-referencing foreign key situation.  an importer can still
+        # "support" these fields, but they're excluded from the simple set for
+        # sake of rattail <-> rattail
         fields.remove('regular_price_uuid')
+        fields.remove('tpr_price_uuid')
+        fields.remove('sale_price_uuid')
         fields.remove('current_price_uuid')
         return fields
 
+    def query(self):
+        query = super(ProductImporter, self).query()
+
+        # make sure potential unit items (i.e. rows with NULL unit_uuid) come
+        # first, so they will be created before pack items reference them
+        # cf. https://www.postgresql.org/docs/current/static/queries-order.html
+        # cf. https://stackoverflow.com/a/7622046
+        query = query.order_by(self.host_model_class.unit_uuid.desc())
+
+        return query
+
 
 class ProductCodeImporter(FromRattail, model.ProductCodeImporter):
     pass
@@ -322,11 +407,18 @@ class ProductCostImporter(FromRattail, model.ProductCostImporter):
     pass
 
 class ProductPriceImporter(FromRattail, model.ProductPriceImporter):
-    pass
+
+    @property
+    def supported_fields(self):
+        return super(ProductPriceImporter, self).supported_fields + self.product_reference_fields
+
 
 class ProductStoreInfoImporter(FromRattail, model.ProductStoreInfoImporter):
     pass
 
+class ProductVolatileImporter(FromRattail, model.ProductVolatileImporter):
+    pass
+
 
 class ProductImageImporter(FromRattail, model.ProductImageImporter):
     """
@@ -339,3 +431,15 @@ class ProductImageImporter(FromRattail, model.ProductImageImporter):
         query = self.host_session.query(self.model_class)\
                                  .order_by(self.model_class.uuid)
         return query[self.host_index:self.host_index + self.batch_size]
+
+
+class LabelProfileImporter(FromRattail, model.LabelProfileImporter):
+
+    def query(self):
+        query = super(LabelProfileImporter, self).query()
+
+        if not self.config.getbool('rattail', 'labels.sync_all_profiles', default=False):
+            # only fetch labels from host which are marked as "sync me"
+            query = query .filter(self.model_class.sync_me == True)
+
+        return query.order_by(self.model_class.ordinal)
