@@ -62,6 +62,10 @@ class FromRattailToRattailVersions(FromRattailHandler, ToRattailHandler):
         importers['CustomerPerson'] = CustomerPersonImporter
         importers['CustomerGroup'] = CustomerGroupImporter
         importers['CustomerGroupAssignment'] = CustomerGroupAssignmentImporter
+        importers['Member'] = MemberImporter
+        importers['MemberPhoneNumber'] = MemberPhoneNumberImporter
+        importers['MemberEmailAddress'] = MemberEmailAddressImporter
+        importers['MemberMailingAddress'] = MemberMailingAddressImporter
         importers['Employee'] = EmployeeImporter
         importers['EmployeePhoneNumber'] = EmployeePhoneNumberImporter
         importers['EmployeeEmailAddress'] = EmployeeEmailAddressImporter
@@ -211,6 +215,18 @@ class CustomerGroupImporter(VersionImporter):
 class CustomerGroupAssignmentImporter(VersionImporter):
     host_model_class = model.CustomerGroupAssignment
 
+class MemberImporter(VersionImporter):
+    host_model_class = model.Member
+
+class MemberPhoneNumberImporter(VersionImporter):
+    host_model_class = model.MemberPhoneNumber
+
+class MemberEmailAddressImporter(VersionImporter):
+    host_model_class = model.MemberEmailAddress
+
+class MemberMailingAddressImporter(VersionImporter):
+    host_model_class = model.MemberMailingAddress
+
 class EmployeeImporter(VersionImporter):
     host_model_class = model.Employee
 
