@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,11 @@
 Batch Stuff
 """
 
-from __future__ import unicode_literals
+from __future__ import unicode_literals, absolute_import
 
-import ConfigParser
+from six.moves import configparser
 
+import six
 import lockfile
 
 from rattail.config import get_user_file
@@ -41,7 +42,7 @@ def consume_batch_id(source='RATAIL'):
     path = get_user_file('rattail.conf', createdir=True)
     with lockfile.LockFile(path):
 
-        parser = ConfigParser.SafeConfigParser()
+        parser = configparser.SafeConfigParser()
         parser.read(path)
         option = 'next_batch_id.{0}'.format(source)
 
@@ -53,7 +54,7 @@ def consume_batch_id(source='RATAIL'):
 
         if not parser.has_section('rattail.sil'):
             parser.add_section('rattail.sil')
-        parser.set('rattail.sil', option, unicode(batch_id + 1))
+        parser.set('rattail.sil', option, six.text_type(batch_id + 1))
 
         with open(path, 'wt') as f:
             parser.write(f)
